@@ -1,15 +1,10 @@
-from django.contrib.contenttypes.models import ContentType
-from django.db.models import Sum, FloatField, IntegerField, DecimalField
-from django.db.models.functions import Cast
-
 from decimal import Decimal
 
-from django.shortcuts import get_object_or_404
+from django.db.models import DecimalField
 
 from netbox import settings
 from netbox.views.generic import ObjectView, ObjectListView, ObjectEditView, ObjectDeleteView, BulkImportView, \
     BulkEditView, BulkDeleteView
-
 from ocp_project_plugin.filters import OCPProjectFilter
 from ocp_project_plugin.forms import (
     OCPProjectImportForm,
